@@ -4,6 +4,9 @@
 
 from ._arraykit import __version__
 from ._arraykit import ArrayGO as ArrayGO
+from ._arraykit import BlockIndex as BlockIndex
+from ._arraykit import ErrorInitBlocks as ErrorInitBlocks
+
 from ._arraykit import immutable_filter as immutable_filter
 from ._arraykit import mloc as mloc
 from ._arraykit import name_filter as name_filter
